@@ -1,7 +1,7 @@
-__version__ = "0.8.6"
+__version__ = "1.0.0"
 
 from mkapi.core.module import get_module
 from mkapi.core.node import get_node
-from mkapi.utils import display, get_html
+from mkapi.main import display, get_html
 
 __all__ = ["get_node", "get_module", "get_html", "display"]
