@@ -2,33 +2,30 @@
 import inspect
 import os
 from dataclasses import dataclass, field
-from typing import Iterator, List, Optional
+from typing import Dict, Iterator, List, Optional
 
-from mkapi.core.node import get_kind
+from mkapi.core.node import Node, get_kind, get_node
 from mkapi.core.object import get_object, get_sourcefile_and_lineno
-from mkapi.core.tree import Tree
+from mkapi.core.structure import Tree
 
 
-@dataclass
+@dataclass(repr=False)
 class Module(Tree):
     """Module class represents an module.
 
     Attributes:
         parent: Parent Module instance.
         members: Member Module instances.
-        objects: If self is module, object member names are
-            collected in this list.
+        node: Node inspect of self.
     """
 
-    parent: Optional["Module"] = field(default=None, init=False, repr=False)
-    members: List["Module"] = field(init=False, repr=False)
-    objects: List[str] = field(default_factory=list, init=False)
+    parent: Optional["Module"] = field(default=None, init=False)
+    members: List["Module"] = field(init=False)
+    node: Node = field(init=False)
 
     def __post_init__(self):
         super().__post_init__()
-        if self.object.kind == "module":
-            objects = get_objects(self.obj)
-            self.objects = [".".join([self.object.id, obj]) for obj in objects]
+        self.node = get_node(self.obj, use_cache=False)
 
     def __iter__(self) -> Iterator["Module"]:
         if self.docstring:
@@ -101,6 +98,9 @@ def get_members(obj) -> List[Module]:
     return members
 
 
+modules: Dict[str, Module] = {}
+
+
 def get_module(name) -> Module:
     """Returns a Module instace by name or object.
 
@@ -112,4 +112,10 @@ def get_module(name) -> Module:
     else:
         obj = name
 
-    return Module(obj)
+    name = obj.__name__
+    if name in modules:
+        return modules[name]
+    else:
+        module = Module(obj)
+        modules[name] = module
+        return module
